@@ -435,7 +435,7 @@ class GDrive():
         ).execute()
         return file.get('id')
     
-    def createGDriveFolder(folderPrefix, parentID=None):
+    def createGDriveFolder(self, folderPrefix, parentID=None):
         # Create a folder in Drive, returns the newely created folders ID
         # Then create a spreadsheet in that folder
         folder_metadata = {
@@ -444,6 +444,8 @@ class GDrive():
         }
         if parentID:
             folder_metadata['parents'] = [{'id': parentID}]
+        folder = self.service.files().create(body=folder_metadata, fields='id').execute()
+        return folder.get('id')
 
 class BigQuery():
     apiDocs = [
